---
title: <span class="badge object-type-scalar"></span> Milliseconds
---
# <span class="badge object-type-scalar"></span> Milliseconds

Time: milliseconds (ms)

## Definition

```python
# Time: milliseconds (ms)
Milliseconds: typing.Literal["ms"] = "ms"
```
